#
# spec file for package python-extension-helpers
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-extension-helpers
Version:        1.4.0
Release:        1.1
Summary:        Utilities for building and installing packages wuth compiled extensions
License:        BSD-3-Clause
URL:            https://github.com/astropy/extension-helpers
Source:         https://files.pythonhosted.org/packages/source/e/extension_helpers/extension_helpers-%{version}.tar.gz
Source100:      python-extension-helpers-rpmlintrc
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 64}
BuildRequires:  %{python_module setuptools_scm >= 6.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
BuildRequires:  %{python_module wheel}
# /SECTION
Requires:       python-setuptools >= 64
Requires:       (python-tomli if python-base < 3.11)
BuildArch:      noarch
%python_subpackages

%description
A package that includes convenience helpers to assist with building Python
packages with compiled C/Cython extensions. It is developed by the Astropy
project but is intended to be general and usable by any Python package.

This is not a traditional package in the sense that it is not intended to be
installed directly by users or developers. Instead, it is meant to be accessed
when the setup.py command is run and should be defined as a build-time
dependency in pyproject.toml files.

%prep
%setup -q -n extension_helpers-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# mismatch: can't build and don't neeed limited api cp310 in our flavored environment
donttest="test_limited_api and cp310"
%pytest --pyargs extension_helpers -k "not ($donttest)"

%files %{python_files}
%doc CHANGES.md README.rst
%license LICENSE.rst licenses/LICENSE_ASTROSCRAPPY.rst
%{python_sitelib}/extension_helpers
%{python_sitelib}/extension_helpers-%{version}.dist-info

%changelog
* Sun Jul 13 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.4.0
  * Allow opting in to limited API builds with
    EXTENSION_HELPERS_PY_LIMITED_API by @astrofrog in #110
- Release 1.3.0
  * Automatically set compiler flags to target PEP 384 Python
    limited API by @lpsinger in #26
  * Bump minimum version of Python to 3.10 and update versions by
    @astrofrog in #106
- Release 1.2.0
  * Support pathlib.Path in write_if_different and import_file by
    @astrofrog in #84
  * TST: fix pyproject-only test (ensure build-time dependencies
    are installed) by @neutrinoceros in #80
  * TST: drop legacy pytest fixture tmpdir, use tmp_path instead by
    @neutrinoceros in #81
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * get_extensions: use shutil.copyfile to avoid PermissionError
  * Fix bug that caused extension-helpers to not work correctly
    if pyproject was the only configuration file present
  * Replace all instances of distutils in docs with setuptools
  * MNT: handle deprecation warnings seen in tests
  * Add note about pinning extension-helpers
  * DEP: drop dependency on tomli on Python 3.11 and newer
  * TST: treat warnings as errors
  * MNT: find and replace log.warn -> log.warning (the warn
    method is deprecated)
  * Infrastructure updates
  * Bump actions/checkout from 2 to 4
  * Bump stefanzweifel/git-auto-commit-action from 4 to 5
  * Add back support for absolute source paths but deprecate it
- update to 1.1.0:
  * Support enabling via `pyproject.toml`
  * OpenMP functions should detect the Intel oneAPI compiler
  * Skip hypothesis tests in downstream testing
  * Set language for docs
  * Update python requirements
  * Add pre-commit configuration
  * Set testpaths to avoid picking up other tests
  * Added configuration required to update changelog when doing
    release through GitHub UI
* Tue Apr  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.0
  * Added support for coverage>=5 for the extension-helpers test
    suite. [#24]
  * Removed any direct usage of distutils. [#34]
  * Remove support for the undocumented --compiler argument to
    setup.py. [#36]
  * Added support for enabling extension-helpers from setup.cfg.
    [#33]
* Sat Feb 20 2021 Ben Greiner <code@bnavigator.de>
- Don't test python36-numpy. Numpy 1.20 in Tumbleweed dropped
  python36 (NEP 29)
* Sun Jul  5 2020 Benjamin Greiner <code@bnavigator.de>
- initial package for vesion 0.1
